==> nui_mini_program-0.0.33.tar.gz: lib/nui_mini_program.dart <==
library nui_hybrid_app;

import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_database/nui_database.dart';
import 'package:nui_mini_program/database/nui_miniprogram_database.dart';
import 'package:nui_mini_program/util/nui_miniprogram_file_manager.dart';
import 'model/nui_miniprogram_module.dart';

export 'engine/nui_miniprogram_js_engine.dart';
export 'model/nui_miniprogram_module.dart';
export 'util/nui_miniprogram_file_manager.dart';
export 'widget/nui_miniprogram_widget.dart';
export 'database/nui_miniprogram_database.dart';

//The module, check if the files are downloaded, else download
//The renderer (Webview) with html, css, js
//The JSEngine, invoke javascript to/from webview and app
//Comman interfaces?

abstract class NUIMiniProgramContainerInterface{
  Future<bool> hasMiniProgram(NUIMiniProgramModule module);
  Future<bool> hasMiniProgramUpdate(NUIMiniProgramModule module);
  Future<String> initializedProgram(NUIMiniProgramModule module);
  Future<bool> downloadAllMiniPrograms(List<NUIMiniProgramModule> modules);
}

class NUIMiniProgramContainer with NUIMiniProgramContainerInterface{
  NUIMiniProgramContainer._builder(NUIMiniProgramContainerBuilder builder){
    _modules = builder._modules;
    _instance = this;
  }
  static NUIMiniProgramContainer _instance;
  List<NUIMiniProgramModule> _modules;

  static NUIMiniProgramContainer get instance => _instance;

  Future<bool> buildDatabase() async{
    //Build database
    final db = NUIDatabaseBuilder()
        .readyCallback((success, message) {})
        .model(NUIMiniProgramDatabase())
        .build();

    await db;
    return true;
  }

  @override
  Future<bool> downloadAllMiniPrograms(List<NUIMiniProgramModule> modules) async{
    List<Future<String>> futures = [];
    _modules.forEach((element) {
      futures.add(initializedProgram(element));
    });

    await Future.wait(futures);
    return true;
  }

  @override
  Future<bool> hasMiniProgram(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return manager.hasMiniProgram();
  }

  @override
  Future<bool> hasMiniProgramUpdate(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return manager.hasMiniProgramUpdate();
  }

  @override
  Future<String> initializedProgram(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return await manager.initializeMiniProgram();
  }
}

class NUIMiniProgramContainerBuilder{
  List<NUIMiniProgramModule> _modules = [];

  NUIMiniProgramContainerBuilder modules(List<NUIMiniProgramModule> modules){
    _modules.addAll(modules);
    return this;
  }

  Future<NUIMiniProgramContainer> build() async{
    final hybrid = NUIMiniProgramContainer._builder(this);
    await hybrid.buildDatabase();
    logNUI("NUIHybridApp", "Initialization complete");
    return hybrid;
  }
}

==> nui_mini_program-1.0.8.tar.gz: lib/nui_mini_program.dart <==
library nui_hybrid_app;

import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_database/nui_database.dart';
import 'package:nui_mini_program/database/nui_miniprogram_database.dart';
import 'package:nui_mini_program/util/nui_miniprogram_file_manager.dart';
import 'model/nui_miniprogram_module.dart';

export 'engine/nui_miniprogram_js_engine.dart';
export 'model/nui_miniprogram_module.dart';
export 'util/nui_miniprogram_file_manager.dart';
export 'widget/nui_miniprogram_widget.dart';
export 'database/nui_miniprogram_database.dart';

//The module, check if the files are downloaded, else download
//The renderer (Webview) with html, css, js
//The JSEngine, invoke javascript to/from webview and app
//Comman interfaces?

abstract class NUIMiniProgramContainerInterface{
  Future<bool> hasMiniProgram(NUIMiniProgramModule module);
  Future<bool> hasMiniProgramUpdate(NUIMiniProgramModule module);
  Future<String> initializedProgram(NUIMiniProgramModule module);
  Future<bool> downloadAllMiniPrograms(List<NUIMiniProgramModule> modules);
}

class NUIMiniProgramContainer with NUIMiniProgramContainerInterface{
  NUIMiniProgramContainer._builder(NUIMiniProgramContainerBuilder builder){
    _modules = builder._modules;
    _instance = this;
  }
  static NUIMiniProgramContainer? _instance;
  late List<NUIMiniProgramModule> _modules;

  static NUIMiniProgramContainer get instance => _instance!;

  Future<bool> buildDatabase() async{
    //Build database
    final db = NUIDatabaseBuilder()
        .readyCallback((success, message) {})
        .model(NUIMiniProgramDatabase())
        .build();

    await db;
    return true;
  }

  @override
  Future<bool> downloadAllMiniPrograms(List<NUIMiniProgramModule> modules) async{
    List<Future<String>> futures = [];
    _modules.forEach((element) {
      futures.add(initializedProgram(element));
    });

    await Future.wait(futures);
    return true;
  }

  @override
  Future<bool> hasMiniProgram(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return manager.hasMiniProgram();
  }

  @override
  Future<bool> hasMiniProgramUpdate(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return manager.hasMiniProgramUpdate();
  }

  @override
  Future<String> initializedProgram(NUIMiniProgramModule module) async{
    final manager = NUIMiniProgramFileManager(module);
    return await manager.initializeMiniProgram();
  }
}

class NUIMiniProgramContainerBuilder{
  List<NUIMiniProgramModule> _modules = [];

  NUIMiniProgramContainerBuilder modules(List<NUIMiniProgramModule> modules){
    _modules.addAll(modules);
    return this;
  }

  Future<NUIMiniProgramContainer> build() async{
    final hybrid = NUIMiniProgramContainer._builder(this);
    await hybrid.buildDatabase();
    logNUI("NUIHybridApp", "Initialization complete");
    return hybrid;
  }
}
